==============================
Acknowledging or citing btrack
==============================

More details of the tracking algorithm can be found in the following publication:

| **Automated deep lineage tree analysis using a Bayesian single cell tracking approach**
| Ulicna K, Vallardi G, Charras G and Lowe AR.
| *Front in Comp Sci* (2021)
| |DOI-U2021|


.. code-block:: bibtex

   @ARTICLE {Ulicna:2021,
      AUTHOR = {Ulicna, Kristina and Vallardi, Giulia and Charras, Guillaume and Lowe, Alan R.},
      TITLE = {Automated Deep Lineage Tree Analysis Using a Bayesian Single Cell Tracking Approach},
      JOURNAL = {Frontiers in Computer Science},
      VOLUME = {3},
      PAGES = {92},
      YEAR = {2021},
      URL = {https://www.frontiersin.org/article/10.3389/fcomp.2021.734559},
      DOI = {10.3389/fcomp.2021.734559},
      ISSN = {2624-9898}
   }


.. |DOI-U2021| image:: https://img.shields.io/badge/doi-10.3389%2Ffcomp.2021.734559-blue
   :target: https://doi.org/10.3389/fcomp.2021.734559
